==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/plugin/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Fil <fil@meteopt.com>
 * @author André Neves <drakferion@gmail.com>
 * @author José Campos zecarlosdecampos@gmail.com
 */
$lang['menu']                  = 'Gerir Plugins';
$lang['download']              = 'Descarregar e instalar um novo plugin';
$lang['manage']                = 'Plugins Instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'remover';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Descarregar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado em:';
$lang['lastupdate']            = 'Actualizado em:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'Plugin %s actualizado com sucesso.';
$lang['updates']               = 'Os seguintes plguins foram actualizados com sucesso:';
$lang['update_none']           = 'Não foram encontradas actualizações.';
$lang['deleting']              = 'Removendo ...';
$lang['deleted']               = 'Plugin %s removido.';
$lang['downloading']           = 'Descarregando ...';
$lang['downloaded']            = 'Plugin %s instalado com sucesso.';
$lang['downloads']             = 'Os seguintes plguins foram instalados com sucesso:';
$lang['download_none']         = 'Nenhum plugin encontrado ou ocorreu um problema ao descarregar ou instalar.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin não retornou qualquer informação, pode estar inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Sítio:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Impossível descarregar o ficheiro do plugin: %s';
$lang['error_badurl']          = 'URL suspeito ou errado - impossível determinar o ficheiro a partir do URL';
$lang['error_dircreate']       = 'Impossível criar pasta temporária para receber os ficheiros a descarregar';
$lang['error_decompress']      = 'O gestor de plugins foi incapaz de descomprimir o ficheiro transferido. Isto pode ter sido causado por uma má transferência, caso no qual você deverá tentar de novo, ou por um formato de compressão desconhecido, caso no qual você deve instalar o plugin manualmente.';
$lang['error_copy']            = 'Ocorreu um erro na cópia do ficheiro na tentativa de instalar o plugin <em>%s</em>: o disco pode estar cheio ou as permissões de acesso do ficheiro podem estar erradas. Isto pode resultar em um plugin parcialmente instalado e deixar a instalação do seu wiki instável.';
$lang['error_delete']          = 'Ocorreu um erro na tentativa de remover o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso à directoria ou ao ficheiro insuficiente.';
$lang['enabled']               = 'Plugin %s habilitado.';
$lang['notenabled']            = 'Plugin %s não pôde ser habilitado, verifique as permissões.';
$lang['disabled']              = 'Plugin %s desabilitado.';
$lang['notdisabled']           = 'Plugin %s não pôde ser desabilitado, verifique as permissões.';
$lang['packageinstalled']      = 'Pacote de Plugins (%d plugin%s: %s) instalado com sucesso.';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/pt/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Fil <fil@meteopt.com>
 * @author André Neves <drakferion@gmail.com>
 * @author José Campos zecarlosdecampos@gmail.com
 */
$lang['menu']                  = 'Gerir Plugins';
$lang['download']              = 'Descarregar e instalar um novo plugin';
$lang['manage']                = 'Plugins Instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'remover';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Descarregar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado em:';
$lang['lastupdate']            = 'Actualizado em:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'Plugin %s actualizado com sucesso.';
$lang['updates']               = 'Os seguintes plguins foram actualizados com sucesso:';
$lang['update_none']           = 'Não foram encontradas actualizações.';
$lang['deleting']              = 'Removendo ...';
$lang['deleted']               = 'Plugin %s removido.';
$lang['downloading']           = 'Descarregando ...';
$lang['downloaded']            = 'Plugin %s instalado com sucesso.';
$lang['downloads']             = 'Os seguintes plguins foram instalados com sucesso:';
$lang['download_none']         = 'Nenhum plugin encontrado ou ocorreu um problema ao descarregar ou instalar.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin não retornou qualquer informação, pode estar inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Sítio:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Impossível descarregar o ficheiro do plugin: %s';
$lang['error_badurl']          = 'URL suspeito ou errado - impossível determinar o ficheiro a partir do URL';
$lang['error_dircreate']       = 'Impossível criar pasta temporária para receber os ficheiros a descarregar';
$lang['error_decompress']      = 'O gestor de plugins foi incapaz de descomprimir o ficheiro transferido. Isto pode ter sido causado por uma má transferência, caso no qual você deverá tentar de novo, ou por um formato de compressão desconhecido, caso no qual você deve instalar o plugin manualmente.';
$lang['error_copy']            = 'Ocorreu um erro na cópia do ficheiro na tentativa de instalar o plugin <em>%s</em>: o disco pode estar cheio ou as permissões de acesso do ficheiro podem estar erradas. Isto pode resultar em um plugin parcialmente instalado e deixar a instalação do seu wiki instável.';
$lang['error_delete']          = 'Ocorreu um erro na tentativa de remover o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso à directoria ou ao ficheiro insuficiente.';
$lang['enabled']               = 'Plugin %s habilitado.';
$lang['notenabled']            = 'Plugin %s não pôde ser habilitado, verifique as permissões.';
$lang['disabled']              = 'Plugin %s desabilitado.';
$lang['notdisabled']           = 'Plugin %s não pôde ser desabilitado, verifique as permissões.';
$lang['packageinstalled']      = 'Pacote de Plugins (%d plugin(s): %s) instalado com sucesso.';
